/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2022 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 *
 * Don't forget to prefix your containers with your own identifier
 * to avoid any conflicts with others containers.
 */


$(document).ready(function () {
    switch (silkpay_type) {
        case 'alipay':
            alipayScript()
            break;
        case 'wechat':
            wechatScript()
            break;
        case 'visa':
            visaScript();
            break;
        case 'union':
            unionScript();
            break;
    }
})

/**
 * 支付宝逻辑
 */
function alipayScript() {
    const id_order = $('#silkpay_id_order').data('id')
    $.post(silkpay_ajax_path_, {id_order, action: 'getPaymentOrder', type: silkpay_type, ajax: true}, function (json) {
        if (json.hasError) {
            $('.silkpay_link_result').text(json.message)
                .removeClass('btn-secondary')
                .addClass('btn-danger')
                .addClass('text-white')
            $('.silkpay_error_message').text(json.message)
                .css('display', '')
        } else {
            const icon = $('.silkpay_link_icon')
            const title = $('.silkpay_link_title')
            if (json.alipay_plus === true) {
                $('.silkpay_link_result').attr('href', json.generated_code_url)
                icon.attr('src', icon.data('icon'))
                title.css('display', '')
            } else {
                //如果不是alipay plus,就可能是扫码
                if (json.is_mobile) {
                    $('.silkpay_link_result').attr('href', json.generated_code_url)
                    icon.attr('src', icon.data('icon'))
                    title.css('display', '')
                } else {
                    //二维码
                    $('.silkpay_qrcode_img').attr('src', json.generated_code_url)
                    qrcodeTimer()
                }
            }
            getOrderPaidStatus(json.transactionId, id_order, 'alipay')
        }
    }, 'json')
}

function wechatScript() {
    if (is_h5) {
        return;
    }
    const id_order = $('#silkpay_id_order').data('id')
    $.post(silkpay_ajax_path_, {id_order, action: 'getPaymentOrder', type: silkpay_type, ajax: true}, function (json) {
        if (json.hasError) {
            $('.silkpay_error_message').text(json.message)
                .css('display', '')
        } else {
            const icon = $('.silkpay_link_icon')
            const title = $('.silkpay_link_title')
            if (json.is_h5) {
                $('.silkpay_link_result').attr('href', json.generated_code_url)
                icon.attr('src', icon.data('icon'))
                title.css('display', '')
                $('.silkpay_link_result').trigger('click');//自动点击
            } else {
                $('.silkpay_qrcode_img').attr('src', json.generated_code_url)
                qrcodeTimer()
            }
            getOrderPaidStatus(json.transactionId, id_order, 'wechat')
        }
    }, 'json')
}

function visaScript() {
    const id_order = $('#silkpay_id_order').data('id')
    $.post(silkpay_ajax_path_, {id_order, action: 'getPaymentOrder', type: silkpay_type, ajax: true}, function (json) {
        if (json.hasError) {
            $('.silkpay_link_result').text(json.message)
                .removeClass('btn-secondary')
                .addClass('btn-danger')
                .addClass('text-white')
        } else {
            const icon = $('.silkpay_link_icon')
            const title = $('.silkpay_link_title')
            $('.silkpay_link_result').attr('href', json.generated_code_url)
            icon.attr('src', icon.data('icon'))
            title.css('display', '')
            getOrderPaidStatus(json.transactionId, id_order, 'visa')
        }
    }, 'json')
}

function unionScript() {
    const id_order = $('#silkpay_id_order').data('id')
    $.post(silkpay_ajax_path_, {id_order, action: 'getPaymentOrder', type: silkpay_type, ajax: true}, function (json) {
        if (json.hasError) {
            $('.silkpay_link_result').text(json.message)
                .removeClass('btn-secondary')
                .addClass('btn-danger')
                .addClass('text-white')
        } else {
            const icon = $('.silkpay_link_icon')
            const title = $('.silkpay_link_title')
            $('.silkpay_link_result').attr('href', json.generated_code_url)
            icon.attr('src', icon.data('icon'))
            title.css('display', '')
            getOrderPaidStatus(json.transactionId, id_order, 'union')
        }
    }, 'json')
}


function getOrderPaidStatus(transactionId, id_order, type) {
    var timer = setInterval(function () {
        $.post(silkpay_ajax_path, {transactionId, id_order, action: 'getOrderStatus', type}, function (json) {
            if (json.paid == true) {
                clearInterval(timer);
                $('.qrcode_timer').text(json.message);
                window.location.href = json.link;
            }
        }, 'json')
    }, 5000);

    $('#wepay_h5').trigger('click');
}

function toggleShowDetail(ele) {
    let show = $(ele).data('show');
    if (show === true) {
        $('.order_detail').slideUp();
    } else {
        $('.order_detail').slideDown();
    }
    $(ele).data('show', !show);
}
